# EcoDonut

Библиотека для расчёта экологического каркаса используемого на платформе ИДУ

## Как это работает

[Описание работы библиотеки](https://github.com/DDonnyy/EcoDonut/wiki/Описание-алгоритма-работы-библиотеки-Ecodonut-(RUS))

### Результат работы библиотеки на примере Ленинградской области
![image_2025-03-27_20-58-27](https://github.com/user-attachments/assets/c618124c-ac79-480e-805f-7468d886fb6d)
![image_2025-03-27_20-58-28](https://github.com/user-attachments/assets/d8e1375c-8641-4658-a469-36ca022bcdf0)


#### Базовые [примеры](./example) работы с библиотекой 

### Результат симуляции загрязнения воды от промышленных объектов по Санкт-Петербургу, находящихся рядом с реками.
![image](https://github.com/user-attachments/assets/a51e82a7-7e8d-433b-bb9d-2540b7230acd)
